import React from 'react';
import { hydrate, render } from 'react-dom';
import { BrowserRouter, Route, Switch, Redirect } from 'react-router-dom';
import sectionList from './Sections';
import './global.scss';
import RootStoreProvider from './Components/RootStoreProvider';
import Header from './Sections/Header';
import { parseToHashID } from './utils/utils';
import useURLHash from './hooks/useURLHash';
import { SectionName } from './utils/types';
import SectionWrapper from './Components/SectionWrapper';
import NavSocial from './Sections/NavSocial';
import ContainerApp from './Components/ContainerApp';
const Footer = React.lazy(() => import('src/Sections/Footer'));
const App = () => {
    const hash = useURLHash();
    const hashString = React.useRef(sectionList.find(({ name }) => parseToHashID(name) === hash) ? hash : '');
    const [sectionRefs] = React.useState(sectionList.map(() => React.createRef()));
    React.useEffect(() => {
        if (!sectionList.find(({ name }) => parseToHashID(name) === hash)) {
            window.location.hash = parseToHashID(SectionName.HOME);
        }
    }, [hash]);
    React.useEffect(() => {
        const handleResize = () => {
            var _a, _b;
            if (window.innerWidth < 375) {
                (_a = document.body) === null || _a === void 0 ? void 0 : _a.setAttribute('style', `zoom: ${(window.innerWidth / 375) * 100}%;`);
            }
            else if (window.innerWidth > 1920) {
                (_b = document.body) === null || _b === void 0 ? void 0 : _b.setAttribute('style', `zoom: ${(window.innerWidth / 1920) * 100}%;`);
            }
        };
        handleResize();
        window.addEventListener('resize', handleResize);
        return () => window.removeEventListener('resize', handleResize);
    }, []);
    React.useEffect(() => {
        const handleScroll = () => {
            let currentHeight = 0;
            sectionRefs.some((element, idx) => {
                if (!element.current)
                    return false;
                currentHeight = currentHeight + element.current.clientHeight;
                if (window.scrollY + 40 < currentHeight) {
                    if (window.location.hash !== parseToHashID(sectionList[idx].name))
                        window.location.hash = parseToHashID(sectionList[idx].name) || '';
                    return true;
                }
                return false;
            });
        };
        window.addEventListener('scroll', handleScroll);
        return () => window.removeEventListener('scroll', handleScroll);
    }, [sectionRefs]);
    return (React.createElement(BrowserRouter, null,
        React.createElement(Switch, null,
            React.createElement(Route, { path: "/", exact: true },
                React.createElement(React.StrictMode, null,
                    React.createElement(RootStoreProvider, null,
                        React.createElement(React.Suspense, { fallback: null },
                            React.createElement(ContainerApp, null,
                                React.createElement(Header, { refList: sectionRefs, hashString: hashString.current, sections: sectionList }),
                                React.createElement(NavSocial, { hash: hash }),
                                sectionList.map((section, index) => {
                                    const Section = section.component;
                                    return (React.createElement(SectionWrapper, { name: section.name, key: section.name, ref: sectionRefs[index] },
                                        React.createElement(Section, null)));
                                }),
                                React.createElement(Footer, { refList: sectionRefs })))))),
            React.createElement(Route, { path: "*", render: () => React.createElement(Redirect, { to: "/" }) }))));
};
const rootElement = document.getElementById('app');
if (rootElement.hasChildNodes()) {
    hydrate(React.createElement(App, null), rootElement);
}
else {
    render(React.createElement(App, null), rootElement);
}
